@@ -80,7 +80,7 @@ class Basylic:
             files = {"file": ("uploaded_file", buffer)}
         elif ftp_file:
             filename = os.path.basename(ftp_file)
-            files = {}
+            files = {"file": ("uploaded_file", bytes())}
         elif file_path:
             buffer = open(file_path, "rb")
             filename = os.path.basename(file_path)
